==> haskell-hslogger-1.2.12-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.2.12
id: hslogger-1.2.12-CjXJT9JFWNLDCmHQ1UWiPR
key: hslogger-1.2.12-CjXJT9JFWNLDCmHQ1UWiPR
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/hslogger
synopsis: Versatile logging framework
description:
    hslogger is a logging framework for Haskell, roughly similar to
    Python'\''s logging module.
    .
    hslogger lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  hslogger also
    has a syslog handler built in.
category: Interfaces
abi: b2ffe1c2ed0b56e902fb6c28e9094a08
exposed: True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger
import-dirs: /usr/lib/ghc-8.4.3/site-local/hslogger-1.2.12
library-dirs: /usr/lib/ghc-8.4.3/site-local/hslogger-1.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hslogger-1.2.12
hs-libraries: HShslogger-1.2.12-CjXJT9JFWNLDCmHQ1UWiPR
depends:
    network-2.7.0.2-2RBwCQfuJsIKkUEqILG4bZ mtl-2.2.2 unix-2.7.2.2
    base-4.11.1.0 containers-0.5.11.0 directory-1.3.1.5 process-1.6.3.0
    time-1.8.0.2 old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
abi-depends: network-2.7.0.2-2RBwCQfuJsIKkUEqILG4bZ=0d494d78cf83103492e5ffc3d4798d79
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslogger-1.2.12-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.2.12
id: hslogger-1.2.12-4sZp21HI9uSAnOLyBpCz9I
key: hslogger-1.2.12-4sZp21HI9uSAnOLyBpCz9I
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/hslogger
synopsis: Versatile logging framework
description:
    hslogger is a logging framework for Haskell, roughly similar to
    Python'\''s logging module.
    .
    hslogger lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  hslogger also
    has a syslog handler built in.
category: Interfaces
abi: f53c6df78301a6bf14a59a6fe29a5cdd
exposed: True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger
import-dirs: /usr/lib/ghc-8.4.3/site-local/hslogger-1.2.12
library-dirs: /usr/lib/ghc-8.4.3/site-local/hslogger-1.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hslogger-1.2.12
hs-libraries: HShslogger-1.2.12-4sZp21HI9uSAnOLyBpCz9I
depends:
    network-2.7.0.2-LgHK7D01MTj1Jd51bZLfR6 mtl-2.2.2 unix-2.7.2.2
    base-4.11.1.0 containers-0.5.11.0 directory-1.3.1.5 process-1.6.3.0
    time-1.8.0.2 old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
abi-depends: network-2.7.0.2-LgHK7D01MTj1Jd51bZLfR6=330c7805fe7a28a7f81311ba9bcc7e3f
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
